use 5.14.0;
use Moops;

our $VERSION = '0.1301'; # VERSION
# PODNAME: OpenGbg::Types
# ABSTRACT: Type library

library  OpenGbg::Types

extends  Types::Standard,
         Types::Path::Tiny,
         Types::DateTime
{

}

1;

__END__

=pod

=encoding UTF-8

=head1 NAME

OpenGbg::Types - Type library

=head1 VERSION

Version 0.1301, released 2015-01-16.

=head1 SOURCE

L<https://github.com/Csson/p5-OpenGbg>

=head1 HOMEPAGE

L<https://metacpan.org/release/OpenGbg>

=head1 AUTHOR

Erik Carlsson <info@code301.com>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2015 by Erik Carlsson.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut
